/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React from 'react';
import axios from 'axios';
import {apiUrl} from '../env';
import {Col,Row} from 'react-grid-system';
import Paper from '@material-ui/core/Paper';
import Typography from '@material-ui/core/Typography';
import CardContent from '@material-ui/core/CardContent';
import Collapse from '@material-ui/core/Collapse';
import CardMedia from '@material-ui/core/CardMedia';
import CardActions from '@material-ui/core/CardActions';
import Coment from './Coment';
import Rating from '@material-ui/lab/Rating';
import Tag from './Tags';
import { Hidden } from '@material-ui/core';
import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';
import Menu from '@material-ui/core/Menu';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import MenuItem from '@material-ui/core/MenuItem';
import MoreVertIcon from '@material-ui/icons/MoreVert';
/*imagens e icones*/
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import ShareIcon from '@material-ui/icons/Share';
import ReportIcon from '@material-ui/icons/Error';
import AddIcon from '@material-ui/icons/CreateNewFolder';
import FavoriteIcon from '@material-ui/icons/Favorite';
import GetAppIcon from '@material-ui/icons/GetApp';
import StarBorderIcon from '@material-ui/icons/StarBorder';
import RateReviewIcon from '@material-ui/icons/RateReview';
import VisibilityIcon from '@material-ui/icons/Visibility';
import SdCardIcon from '@material-ui/icons/SdCard';
import TranslateIcon from '@material-ui/icons/Translate';
import InsertDriveFileIcon from '@material-ui/icons/InsertDriveFile';
import DateRangeIcon from '@material-ui/icons/DateRange';
import UpdateIcon from '@material-ui/icons/Update';
import AssignmentOutlinedIcon from '@material-ui/icons/AssignmentOutlined';
import OpenIcon from '@material-ui/icons/CallMade';
import { TextField, FormControl } from '@material-ui/core';

import noAvatar from "../img/default_profile.png";
import styled from 'styled-components'



const TypographyStyled = styled(Typography)`
  padding: 5px;
`

const CardActionsStyled = styled(CardActions)`
  padding:0px 0px 10px 0px;
  align-items: center;
`

const PaperStyled = styled(Paper)`
  margin: 2em 0em 2em 0em;
  padding: 2em 2em 0em 2em;
  @media only screen and (min-width :500px ) {
    margin: 2em 10% 2em 10%;
  }
`
const elevateStyle = 3;

const Overlay = styled.div`
  display: inline;
  background: linear-gradient(transparent,transparent,#fff),transparent;
  bottom: 0;
  cursor: pointer;
  left: 0;
  opacity: .8;
  filter: alpha(opacity=80);
  position: absolute;
  right: 0;
  top: 0;
  height: inherit;

`
async function getResource(id){
  let res = await axios.get(`${apiUrl}/learning_objects/${id}`);
  let data = res.data;
  return(data);
}

export default function AboutResource() {

  var display = getResource(19133);
  console.log(display);
  const [anchorEl, setAnchorEl] = React.useState(null);

  function handleClick(event) {
    setAnchorEl(event.currentTarget);
  }

  function handleClose() {
    setAnchorEl(null);
  }
  return (
    <div style={{backgroundColor: "#f4f4f4", padding: "2em 0em 2em 0em"}}>
      <PaperStyled elevation={elevateStyle}>
        <CardMedia image={noAvatar}/>
        <CardContent style={{padding: "0em"}}>
          <Typography variant="h5" color="textSecondary" component="h3">
          {display.name}
          </Typography>
          <CardActionsStyled >
            <IconButton style={{padding: "0px"}}aria-label="Favoritar">
              <FavoriteIcon />
            </IconButton>
            <Rating
              name="customized-empty"
              value={2}
              precision={0.5}
              emptyIcon={<StarBorderIcon fontSize="inherit" />}
            />
            <Hidden smDown>
              <IconButton aria-label="Relatar">
                <RateReviewIcon/>
              </IconButton>
              RELATAR
            </Hidden>
            </CardActionsStyled>
            <CardContent style={{padding: "0em"}}>
              <TypographyStyled component="p" color="textSecondary">
              Tipo de Recurso:
              </TypographyStyled>
              <TypographyStyled component="p" color="textSecondary">
              Componentes Curriculares:
              </TypographyStyled>
              <TypographyStyled component="p" color="textSecondary">
              Outras Temáticas:
              </TypographyStyled>
              <TypographyStyled component="p" color="textSecondary">
              Etapas de Ensino:
              </TypographyStyled>
            </CardContent>
          <Row >
            <Col md={4} sm={12}><VisibilityIcon style={{verticalAlign: "middle"}}/>Visualizações:</Col>
            <Col md={5} sm={12}><GetAppIcon style={{verticalAlign: "middle"}}/>Baixados/Acessados:</Col>
          </Row>
          <CardActions disableSpacing style={{fontSize: "0.7rem", borderRadius: "2px", justifyContent: "space-between", paddingTop: "2em"}}>
            <Hidden smDown>
              <Button  aria-label="Reportar" size="small">
              <ReportIcon />     REPORTAR ABUSO OU ERRO        </Button>
              <Button aria-label="Compartilhar">
              <ShareIcon />   COMPARTILHAR          </Button>
            </Hidden>
            <Button aria-label="Guardar">
            <AddIcon />   GUARDAR          </Button>
            <Button variant="contained" color="secondary">
            <OpenIcon/> Abrir Recurso </Button>
            <Hidden mdUp>
            <Button aria-controls="simple-menu" aria-haspopup="true" onClick={handleClick}>
              <MoreVertIcon/>
            </Button>
            <Menu
              id="simple-menu"
              anchorEl={anchorEl}
              keepMounted
              open={Boolean(anchorEl)}
              onClose={handleClose}
            >
              <MenuItem onClick={handleClose}>
              <ListItemIcon>
                <ShareIcon />
              </ListItemIcon>
              Compartilhar</MenuItem>
              <MenuItem onClick={handleClose}>
              <ListItemIcon>
                <ReportIcon />
              </ListItemIcon>
              Reportar</MenuItem>
            </Menu>
            </Hidden>
          </CardActions>
    </CardContent>
      </PaperStyled>
      <PaperStyled elevation={elevateStyle}>
        <Row style={{padding: "15px"}}>
          <Col md={8} sm={12}>
            <Typography variant="h5" color="textSecondary" component="h3">
            Sobre o Recurso
            </Typography>
            <Typography component="p" color="textSecondary">
            Paper can be used to build surface or other elements for your application.
            </Typography>
            <div style={{paddingTop: "4em"}}>
            <Typography variant="h5" color="textSecondary" component="h3">
            Informações Adicionais</Typography>
            <Tag name="teste"/>
            <Typography component="p" color="textSecondary">
            <SdCardIcon/>Tamanho:
            </Typography>
            <Typography component="p" color="textSecondary">
            <TranslateIcon/>Idioma:
            </Typography>
            <Typography component="p" color="textSecondary">
            <InsertDriveFileIcon/>Formato:
            </Typography>
            <Typography component="p" color="textSecondary">
            <DateRangeIcon/>Data de Envio:
            </Typography>
            <Typography component="p" color="textSecondary">
            <UpdateIcon/>Modificado em:
            </Typography>
            <Typography component="p" color="textSecondary">
            <AssignmentOutlinedIcon/>Tipo de Licença:
            </Typography>
            </div>
          </Col>
          <Col md={4}  sm={12}>
            <div style={{borderLeft:"1px solid #e5e5e5"}}>
              <Typography>
                Enviado por:
              </Typography><br/>
              <img style={{padding: "2em" }} alt="Avatar" src={noAvatar} height="100em"/>
            </div>
          </Col>
      </Row>


      </PaperStyled>
      <PaperStyled elevation={elevateStyle}>
        <CardContent>
            Conte sua experiência com o Recurso
            <Rating
              name="customized-color"
              value={0}
              precision={0.5}
            />
            <Row>
              <Col md={10} sm={12}>
                <TextField fullWidth="true" multiline="true" required="true" placeholder="Escreva aqui sua experiência com o recurso *"/>
              </Col>
              <Col>
                <Button variant="contained" color="primary">submit </Button>
              </Col>
            </Row>

        </CardContent>
        <CardContent>
          <Typography variant="h5" component="p" color="textSecondary">Relatos sobre o uso do Recurso</Typography>
          <Coment author="jorginho" coment="muito bom gostei mto bom msm"/>
        </CardContent>
      </PaperStyled>
    </div>
  );
}
