/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useContext, useState, useEffect } from 'react';
import { Grid } from '@material-ui/core';
import Rating from '@material-ui/lab/Rating';
import IconButton from '@material-ui/core/IconButton';
import StarBorderIcon from '@material-ui/icons/StarBorder';
import FavoriteIcon from '@material-ui/icons/Favorite';
import InfoIcon from '@material-ui/icons/Info';
import axios from 'axios';
import { apiUrl } from '../env';
import { Store } from '../Store.js'
import ReportModal from './ReportModal.js';
import SignUpModal from './SignUpModal.js';
import LoginModal from './LoginModal.js';

export default function CollectionReview(props) {
	const [likes, setLikes] = useState(0);
	const [liked, setLiked] = useState(false);
	const [stars, setStars] = useState(0);
	const [reportOpen, setReportOpen] = useState(false);
	const [sign_up_open, setSignUpOpen] = useState(false);
	const [log_in_open, setLoginOpen] = useState(false);
	const { state } = useContext(Store);

	useEffect(() => {
		axios.get(apiUrl + '/collections/' + props.id)
			.then(res => {
				setLikes(Number(res.data.likes_count));
				setLiked(res.data.liked);
			});
	}, [props.id]);

	const handleClickReport = () => {
		setReportOpen(true);
	}

	const SaveNewHeaders = (response) => {
		if (
			(response.headers['access-token'] === undefined || response.headers['access-token'] === null) &&
			(response.headers.client === undefined || response.headers.client === null)
		) {
	
		} else {
			sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
			sessionStorage.setItem('@portalmec/clientToken', response.headers.client)
			console.log('saved')
		}
	}

	const handleLikeClick = () => {
		if (state.currentUser.id) {
			const url = apiUrl + '/collections/' + props.id + '/like';
			if (!liked)
				axios({
					method: 'put',
					url: url,
					headers: {
						'Accept': 'application/json',
						'Content-Type': 'application/json; charset=utf-8',
						'access-token': sessionStorage.getItem('@portalmec/accessToken'),
						'client': sessionStorage.getItem('@portalmec/clientToken'),
						'uid': sessionStorage.getItem('@portalmec/uid'),
						'If-None-Match': null
					},
				}).then(response => {
					if(response.status === 201)
					{
						setLiked(true)
						setLikes(response.data.count);
					}
					else 
					{
						setLiked(false);
						setLikes(response.data.count);
					}
					SaveNewHeaders(response)
				})
			else
				setLiked(!liked);
		} else
			setSignUpOpen(true);
	}

	const handleSetStars = (value) => {
		setStars(value);
		props.scrollToComment();
	}

	const handleCloseModal = () => {
		setReportOpen(false);
	}

	return (
		<Grid container direction="column">
			<Grid sm={12} container direction="row" alignItems="center">
				<Grid item>
					<Rating
						name="customized-empty"
						value={stars}
						onChange={(e, value) => handleSetStars(value)}
						precision={0.5}
						style={{ color: "#666" }}
						emptyIcon={<StarBorderIcon fontSize="inherit" />}
					/>
				</Grid>
				<Grid item justify="center" alignItems="center">
					<IconButton aria-label="like" onClick={handleLikeClick}>
						{likes}<FavoriteIcon style={{fill : liked ? "red" : null}} />
					</IconButton>
				</Grid>
			</Grid>
			<Grid item sm={12}>
				<IconButton
					aria-label="report"
					style={{ fontSize: 'small' }}
					onClick={handleClickReport}>
					<InfoIcon />Reportar erro ou abuso
				</IconButton>
				<ReportModal
					open={reportOpen}
					handleClose={handleCloseModal}
					form="colecao"
					complainableId={props.id}
					complainableType="Collection"
				/>
			</Grid>
			<SignUpModal
				open={sign_up_open}
				handleClose={() => setSignUpOpen(false)}
				openLogin={() => setLoginOpen(true)}
			/>
			<LoginModal
				open={log_in_open}
				handleClose={() => setLoginOpen(false)}
			/>
		</Grid>
	);
}
