/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useRef, useEffect, useContext } from 'react'
import { HashLink as Link } from 'react-router-hash-link';
import { Button, Grow, Paper, Popper, MenuItem, MenuList } from '@material-ui/core';
import { withStyles } from '@material-ui/styles';
import styled from 'styled-components'
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import { Store } from '../Store';

const styles = theme => ({
  root: {
    display: 'flex',

  },
  paper: {
    marginRight: '2px',
  },
});

const DropdownStyled = styled.div`
  *{
    margin: 0 !important;
    text-decoration: none;
  }
  Button{
    text-transform: capitalize;
  }

`


function Dropdown(props) {
  const [open, setOpen] = useState(false);

  const innerDropdown = useRef(null)

  const { state , dispatch } = useContext(Store)

  useEffect(()=>{
    const handleClickOutside = (event) => {
      innerDropdown.current && !innerDropdown.current.contains(event.target) && setOpen(false)
    }

    document.addEventListener('mousedown', handleClickOutside)

    return () => document.removeEventListener('mousedown', handleClickOutside)

  },[])


  const handleToggle = () => {
    setOpen(true)
    if(state.searchOpen)
      dispatch({
        type: 'HANDLE_SEARCH_BAR',
        opened: false
      })
  }

  return (
    <DropdownStyled ref={innerDropdown}>
      <Button
        aria-controls="menu-list-grow"
        aria-haspopup="true"
        onClick={handleToggle}
      >
        {props.name}
        <ExpandMoreIcon/>
      </Button>
      { open &&
        <Popper open={open} keepMounted transition disablePortal placement={'bottom'}>
          {({ TransitionProps, placement }) => (
            <Grow
              {...TransitionProps}
              style={{ transformOrigin: 'center top !important', anchorOrigin : "center bottom !important"}}
            >
              <Paper id="menu-list-grow">
                <MenuList>
                  {
                    props.items.map((item)=>
                      <Link key={`${item.name}_${new Date().toString()}` } to={item.href} ><MenuItem>{item.name}</MenuItem></Link>
                    )
                  }
                </MenuList>
              </Paper>
            </Grow>
          )}
        </Popper>
      }
    </DropdownStyled>
  );
}

export default withStyles(styles)(Dropdown)
