/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react';
import { Grid } from '@material-ui/core';
import styled from 'styled-components';
import axios from 'axios';
import Button from '@material-ui/core/Button';
import CheckBoxOutlineBlankIcon from '@material-ui/icons/CheckBoxOutlineBlank';
import CheckBoxIcon from '@material-ui/icons/CheckBox';
import GetAppIcon from '@material-ui/icons/GetApp';
import ResourceCardFunction from './ResourceCardFunction.js';
import FloatingDownloadButton from './FloatingDownloadButton.js';
import Snackbar from '@material-ui/core/Snackbar';
import MuiAlert from '@material-ui/lab/Alert';
import { apiUrl } from '../env.js';

function Alert(props) {
	return <MuiAlert elevation={6} variant="filled" {...props} />;
}


export default function ResourceList(props) {
	console.log(props);

	const [selected, setSelected] = useState(Array.apply(
		null, { length: props.resources.length }).map(i => false));
	const [selectable, setSelectable] = useState(false);
	const [download_url, setDownloadUrl] = useState('');
	const [snackbar_open, setSnackbarOpen] = useState(false);

	const updateSelected = (index) => {
		let new_selected = selected.slice();
		new_selected[index] = !new_selected[index];
		setSelected(new_selected);
	}

	const checkBoxIcon = (s) => {
		if (s)
			return <CheckBoxIcon />;
		else
			return <CheckBoxOutlineBlankIcon />;
	}

	const handleDownloadSelection = () => {
		// const selected_resources = props.resources.filter(resource => selected[props.resources.indexOf(resource)]);
		setSnackbarOpen(true);
	}

	useEffect(() => {
		if (selectable) {
			var resources = []
			let i = 0;
			while (i < props.resources.length) {
				if (selected[i])
					resources.push({ "type": "LearningObject", "id": props.resources[i].id });
				i++;
			}
			const body = {
				"package": {
					"object": resources
				}
			};
			if (resources.length)
				axios
					.post(apiUrl + '/package', body)
					.catch(err => {
						if (err.response && err.response.status === 302) {
							setDownloadUrl(apiUrl.slice().replace('/v1', '') + '/' + err.response.data.url);
						}
					});
		}
	}, [selected, selectable]);

	return (
		<ResourceListContainer>
			<Grid container direction="row" justify="space-around" alignItems="center">
				<Grid item>
					<Title>
						{props.resources.length ?
							props.resources.length + " recurso" + (props.resources.length === 1 ? "" : "s")
							: "Carregando coleção"}
					</Title>
				</Grid>
				<Grid item>
					<Button color="primary" onClick={() => setSelectable(!selectable)}>
						<PanelButtonText>
							{selectable ? "Desativar" : "Ativar"} seleção
						</PanelButtonText>
					</Button>
				</Grid>
				<Grid item>
					<UnstyledAnchor href={download_url}>
						<Button
							color="primary"
							variant="outlined"
							startIcon={<GetAppIcon fontSize="large" />}
							onClick={handleDownloadSelection}
						>
							<PanelButtonText>baixar seleção</PanelButtonText>
						</Button>
					</UnstyledAnchor>
				</Grid>
			</Grid>
			<Grid container direction="row" justify="flex-start" alignItems="center">
				{props.resources.map((r) => {
					console.log(r);
					return (
						<ResourceGrid item key={r.title}>
							<ResourceCardFunction
								avatar={r.avatar}
								id={r.id}
								thumbnail={r.thumbnail}
								type={r.object_type ? r.object_type : "Outros"}
								title={r.name}
								published={r.state === "published" ? true : false}
								likeCount={r.likes_count}
								liked={r.liked}
								rating={r.review_average}
								author={r.title}
								tags={r.tags}
								href={"/recurso/" + r.id}
								downloadableLink={r.default_attachment_location}
							/>
							{selectable ?
								(<SelectButton
									variant="outline"
									color="primary"
									startIcon={checkBoxIcon(selected[props.resources.indexOf(r)])}
									onClick={() => updateSelected(props.resources.indexOf(r))}
								>
									Selecionar
								</SelectButton>)
								:
								<span></span>}

						</ResourceGrid>
					);
				})}
			</Grid>
			<Snackbar
				open={snackbar_open}
				autoHideDuration={6000}
				onClose={() => setSnackbarOpen(false)}
				anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
			>
				<Alert onClose={() => setSnackbarOpen(false)} severity="info">
					Os recursos serão baixados
				</Alert>
			</Snackbar>
			<FloatingDownloadButton url={download_url} empty={selected.indexOf(true) === -1} />
		</ResourceListContainer>
	);
}

const ResourceListContainer = styled.div`
	margin-left: 20;
	margin-right: 20;
`
const Title = styled.p`
	color: rgb(102, 102, 102);
	font-size: 2em;
	font-weigth: 300;
`
const SelectButton = styled(Button)`
	width: 100%;
`
const PanelButtonText = styled.span` 
	font-weight: 900;
`
const ResourceGrid = styled(Grid)`
	padding-right: 7px;
`
const UnstyledAnchor = styled.a`
	text-decoration: none !important;
`
