/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect} from 'react'
import axios from 'axios'
import {apiUrl} from '../../../env';
import LoadingSpinner from '../../LoadingSpinner.js'
import TemplateCuradoria from '../PanelComponents/TemplateCuradoria.js'

export default function TabPanelCuradoria (props) {
    const [loading, handleLoading] = useState(true)

    const [submissions, setSubmissions] = useState([])
    const [submissionsSlice, setSubmissionsSlice] = useState([])

    const showMoreSubmissions = () => {
        var sliceLength = submissionsSlice.length
        setSubmissionsSlice(submissions.slice(0, sliceLength + 4))
    }

    const showAllSubmissions = () => {setSubmissionsSlice(submissions)}

    useEffect( () => {
        axios.get( (`${apiUrl}/users/` + props.id + '/submissions?offset=0&status=submitted'), props.config)
            .then(response => {
                console.log(response)
                if (response.headers['access-token']) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }

                handleLoading(false)
                setSubmissions(response.data)
                setSubmissionsSlice(response.data.slice(0,4))

            }, error => {console.log('error while running ComponentDidMout on TabPanelCuradoria')})
    }, [])

    return (
        <React.Fragment>
            {
                loading ?
                 (
                     <LoadingSpinner text={"Carregando Recursos"}/>
                 )
                 :
                 (
                     [
                         <React.Fragment>
                             <TemplateCuradoria
                                 length={submissions.length}
                                 titleText = {"Recursos a serem curados"}
                                 noContentText = {"Você não tem nenhum recurso para ser avaliado"}
                                 sliceArr={submissionsSlice}
                                 showMore={showMoreSubmissions}
                                 showAll={showAllSubmissions}
                             />
                         </React.Fragment>
                     ]
                 )
             }
        </React.Fragment>
    )
}
