/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState} from 'react'
import UndoIcon from '@material-ui/icons/Undo';
import {WrapperBox, StyledTextField, BlueButton, GrayButton} from './StyledComponents.js'

export default function ChooseLink (props) {
    const [linkSent, setLinkSent] = useState(false)
    const [link, setLink] = useState({flag : false, value : ""})
    const handleLink = (e) => {
        let userInput = e.target.value
        const urlRegex = new RegExp(
            // eslint-disable-next-line
            "(?:(?:(?:https?|ftp):\/\/))(?:\S+(?::\S*)?@)?(?:(?!(?:10|127)(?:\.\d{1,3}){3})(?!(?:169\.254|192\.168)(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)(?:\.(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)*(?:\.(?:[a-z\u00a1-\uffff]{2,}))\.?)(?::\d{2,5})*(?:[/?#]\S*)?", "i"
        )
        let flag = !(urlRegex.test(userInput))
        setLink({...link,
            flag : flag,
            value : userInput}
        )
    }

    const handleSubmit = (e) => {
        e.preventDefault()
        console.log(link.flag)
        if (!link.flag) {
            props.submit(link.value)
            setLinkSent(true)
        }
    }


    return (
        <WrapperBox>
            <div className="inner">
                <div className="upload-title"> Enviar Link</div>

                <div className="flex-column">
                    <p>Insira o link da página do recurso abaixo:</p>
                    <form onSubmit={(e) => {handleSubmit(e)}}>
                        <StyledTextField
                            id = {"choose-link-form"}
                            label={"Exemplo: http://google.com"}
                            type = {"text"}
                            value = {link.value}
                            onChange = {e => {handleLink(e)}}
                            helperText = {link.flag ? "Faltou inserir um endereço eletrônico" : ""}
                            multiline={true}
                            rowsMax = {"10"}
                            rows={1}
                            error = {link.flag}
                            required = {true}
                            disabled={linkSent}
                        />

                        <div className="buttons-div">
                        {
                            linkSent ?
                            (
                                <BlueButton onClick={() => {setLinkSent(false)}}>Editar</BlueButton>
                            )
                            :
                            (
                                <>
                                    <GrayButton onClick={() => {props.handleNextStage("default")}}>
                                        <span className="button-text">
                                            <UndoIcon className="icon"/>Voltar
                                        </span>
                                        </GrayButton>
                                    <BlueButton type="submit">SALVAR</BlueButton>
                                </>
                            )
                        }
                    </div>
                    </form>
                </div>
            </div>
        </WrapperBox>
    )
}
