/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect} from 'react'
import CloudUploadIcon from '@material-ui/icons/CloudUpload';
import {DottedBox, BlueButton} from './StyledComponents.js';
import FileToUpload from './FileToUpload'
import {getAxiosConfig} from '../HelperFunctions/getAxiosConfig.js'
import AddAPhotoIcon from '@material-ui/icons/AddAPhoto';

type Props = {
    draftID : string;
}

const UploadMediaComponent: React.FC<Props> = ({draftID, children}) => {
    const [filesToUpload, setFilesToUpload] = useState<FileToUpload | undefined>(undefined);

    const onFileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        const files: FileList | null = e.target.files;
        if(!files) return;

        let fileToUpload: FileToUpload = new FileToUpload(files[0], files[0].name, draftID);

        setFilesToUpload(fileToUpload);
        if (fileToUpload != undefined){
            console.log(fileToUpload.uploadFile())

        }
    };

    return (
        <div className="upload-container">
            <h2 className="upload-title">File Uploader</h2>
            <div className="upload-form">
                <form id="file_upload">
                    <DottedBox

                        >
                        <AddAPhotoIcon className="icon"/>
                        <input
                            type="file"
                            onChange = {onFileChange}
                            id="upload-file-thumbnail"
                            style={{display : "none"}}
                            />
                        <BlueButton>
                            <label htmlFor="upload-file-thumbnail" style={{width : "inherit", cursor : "pointer"}}>
                                ESCOLHER IMAGEM
                            </label>
                        </BlueButton>
                        <span style={{marginTop : "6px"}}>Ou arrastar e soltar o arquivo aqui</span>
                    </DottedBox>
                </form>
            </div>
        </div>
    )
}
UploadMediaComponent.displayName = 'UploadMedia';
export default UploadMediaComponent;

{/*<div className="upload-file-select">
    <label htmlFor="file_1">Select files for upload</label>
    <input id="file_1" type="file" multiple onChange={onFileChange}/>
</div>

<div className="upload-file-list">
    {filesToUpload.map((f,i) => <div className="upload-file" key={i}>{f.name} - {f.file.size}bytes</div>)}
</div>

<div className="upload-submit">
    <input type="submit" value="submit"/>
</div>*/}

{/*
    const [dropDepth, setDropDepth] = useState(0)
    const [inDropZone, toggleInDropZone] = useState(false)
    const [fileList, setFileList] = useState([])

    const handleDragEnter = e => {
        e.preventDefault();
        e.stopPropagation();

        setDropDepth(dropDepth + 1)
    };

    const handleDragLeave = e => {
        e.preventDefault();
        e.stopPropagation();

        setDropDepth(dropDepth - 1)
        if (dropDepth > 0)
            toggleInDropZone(true)
    };

    const handleDragOver = e => {
        e.preventDefault();
        e.stopPropagation();
        e.dataTransfer.dropEffect = 'copy';
        toggleInDropZone(true)
    };

    const handleDrop = e => {
        e.preventDefault();
        e.stopPropagation();
        let files = [...e.dataTransfer.files]

        if (files && files.length > 0) {
            props.acceptFile(files[0])
        }
    };

    const handleUpload = (e, selectorFiles : FileList) => {
        e.preventDefault();
        props.acceptFile(selectorFiles[0])
    }


    <DottedBox
    onDrop={e => handleDrop(e)}
    onDragOver={e => handleDragOver(e)}
    onDragEnter={e => handleDragEnter(e)}
    onDragLeave={e => handleDragLeave(e)}
    >
    <CloudUploadIcon className="icon"/>
    <input
        type="file"
        onChange = {(e) => handleUpload(e, e.target.files)}
        id="upload-file"
        style={{display : "none"}}
        />
    <BlueButton>
        <label htmlFor="upload-file" style={{width : "inherit", cursor : "pointer"}}>
            ESCOLHER O ARQUIVO
        </label>
    </BlueButton>
    <span style={{marginTop : "6px"}}>Ou arrastar e soltar o arquivo aqui</span>
</DottedBox>
    */}
