/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect} from 'react'
import Grid from '@material-ui/core/Grid';
import styled from 'styled-components'
import axios from 'axios'
import {apiUrl} from '../../env';
import DragAndDropThumbnail from './PartTwoComponents/DragAndDropThumbnail'
import EducationalStage from './PartTwoComponents/EducationalStage'
import Licenca from './PartTwoComponents/Licenca'
import Checkbox from '@material-ui/core/Checkbox';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import FormControl from '@material-ui/core/FormControl';
import {StyledFormLabel} from './StyledComponents.js'
import ButtonsDiv from './ButtonsDiv.js'
import SubjectsAndThemes from './PartTwoComponents/SubjectsAndThemes.js'
import {SendInfo} from './SendInfo.js'
import EditThumbnail from './PartTwoComponents/EditThumbnail.js'
import {getAxiosConfig} from '../HelperFunctions/getAxiosConfig'
import DisplayThumbnail from './PartTwoComponents/DisplayThumbnail.js'
import CustomCircularProgress from './PartTwoComponents/CustomCircularProgress';

export function LoadingDiv () {
    return (
        <div style={{width : "100%", display : "flex", alignItems : "center", justifyContent : "center", color : "#666"}}>
            <CustomCircularProgress/> CARREGANDO IMAGEM
        </div>
    )
}

export default function PartTwo (props) {
    const [eduStages, setEduStages] = useState([])
    const [subjects, setSubjects] = useState([])
    const [themes, setThemes] = useState([])

    useEffect(() => {
        axios.get(`${apiUrl}/educational_stages/`).then(
            (response) => {console.log(response);
                setEduStages(response.data)
            },
            (error) => {console.log(error)}
        )

        axios.get(`${apiUrl}/subjects/`).then(
            (response) => {console.log(response);
                setSubjects(response.data.filter(subject => subject.theme === false).sort((a,b) => a.name > b.name ? 1 : -1))
                setThemes(response.data.filter(subject => subject.theme === true).sort((a,b) => a.name > b.name ? 1 : -1))
            },
            (error) => {console.log(error)}
        )
    }, [])


     /*------------------------Licenca------------------------*/

     const [termsCheckbox, setChecked]  = useState(false)
     const toggleCheckbox = (event) => {
            setChecked(event.target.checked)
     }

     const [thumbnail, setThumbnail] = useState('')
     const [tempUrl, setTempUrl] = useState('')

     const acceptFile = (file) => {
         const objectURL = URL.createObjectURL(file)
         console.log(file)
         setTempUrl(objectURL)
         setThumbnailStage('editing')
     }
     const updateThumb = (newThumbnail) => {
         setThumbnail(newThumbnail)
         console.log(thumbnail)

     }
     const finalizeThumb = () => {
         setThumbnailStage('uploading')
         let config = getAxiosConfig()
         let fdThumb = new FormData()
         fdThumb.set('learning_object[thumbnail]', thumbnail)
         axios.put((`${apiUrl}/learning_objects/` + props.draftID), fdThumb, config).then(
             (response) => {
                 setThumbnailStage('done')
                 console.log(response.data)
                 if ( response.headers['access-token'] ) {
                     sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                 }
             },
             (error) => {console.log(error)}
         )
     }

     const [thumbnailStage, setThumbnailStage] = useState('default')

     const chooseRenderStageThumbnail = () => {
         switch(thumbnailStage) {
             case 'uploading':
                return (<LoadingDiv/>)
             case 'done':
                return (<DisplayThumbnail acceptFile={acceptFile} thumbnail={thumbnail}/>)
             case 'editing':
                return (<EditThumbnail finalizeThumb={finalizeThumb} tempImgURL={tempUrl} updateThumb={updateThumb}/>)
             default :
                return (<DragAndDropThumbnail acceptFile={acceptFile}/>)

         }
     }

     const handleSubmit = () => {
         props.stepperControl(1)
     }

     return (
        <form style={{width : "100%"}} onSubmit={handleSubmit}>
            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                {chooseRenderStageThumbnail()}
            </Grid>

            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <EducationalStage draftID={props.draftID} eduStages={eduStages} onBlurCallback={SendInfo}/>
            </Grid>

            <SubjectsAndThemes  draftID={props.draftID} subjects={subjects} themes={themes} onUploadPage={true} onBlurCallback={SendInfo}/>

            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <Licenca draftID={props.draftID} onBlurCallback={SendInfo}/>
            </Grid>

            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <StyledFormControl required >
                    <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                        <b>Confirme se você concorda com os <a href="/termos" style={{color : "#ff7f00"}}>termos de uso e de propriedade intelectual</a></b>
                    </StyledFormLabel>
                    <FormControlLabel label={<span className="label">Li e concordo com os termos de uso e de propriedade intelectual.</span>} control={<Checkbox checked={termsCheckbox} onChange={toggleCheckbox}/>}
                        />
                </StyledFormControl>
            </Grid>

            <Grid item xs={12}>
                    <ButtonsDiv draftID={props.draftID} stepperControl={props.stepperControl} onPartTwo={true}/>
            </Grid>

            <Grid item xs={12} style={{marginTop : "20px"}}>
                <span style={{marginTop : "20px", fontWeight : "200", color : "#a5a5a5", paddingLeft : "10px"}}>
                    * Campos obrigatórios
                </span>
            </Grid>
        </form>
    )
}

const StyledFormControl = styled(FormControl)`
    .MuiCheckbox-colorSecondary.Mui-checked {
        color : #00bcd4 !important;
    }

    .label {
        font-size : 14px !important;
        color : #666 !important;
        font-weight : 200 !important;
    }
`
