/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState} from 'react'
import {DottedBox, BlueButton} from '../StyledComponents.js';
import AddAPhotoIcon from '@material-ui/icons/AddAPhoto';
import FormControl from '@material-ui/core/FormControl';
import {StyledFormLabel} from '../StyledComponents.js'

export default function DragAndDropThumbnail (props) {
    const [dropDepth, setDropDepth] = useState(0)
    // eslint-disable-next-line
    const [inDropZone, toggleInDropZone] = useState(false)

    const handleDragEnter = e => {
        e.preventDefault();
        e.stopPropagation();

        setDropDepth(dropDepth + 1)
    };

    const handleDragLeave = e => {
        e.preventDefault();
        e.stopPropagation();

        setDropDepth(dropDepth - 1)
        if (dropDepth > 0)
            toggleInDropZone(true)
    };

    const handleDragOver = e => {
        e.preventDefault();
        e.stopPropagation();
        e.dataTransfer.dropEffect = 'copy';
        toggleInDropZone(true)
    };

    const handleDrop = e => {
        e.preventDefault();
        e.stopPropagation();
        let files = [...e.dataTransfer.files]
        if (files && files.length > 0) {
            props.acceptFile(files)
        }
    };

    const handleUpload = (e, selectorFiles) => {
        e.preventDefault();
        props.acceptFile(selectorFiles[0])
    }
    return (
        <FormControl style={{width : "100%"}}>
            <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                {
                    props.onEditPage ?
                    (
                        <b style={{textAlign : "center", fontSize : "26px", fontWeight : "ligther"}}>Inserir Imagem Ilustrativa</b>
                    )
                    :
                    (
                        <>
                        <b>Imagem Ilustrativa do Recurso</b> <span style={{color : "#a5a5a5"}}>(Deixe seu recurso completo, para que todos o entendam melhor.)</span>
                        </>
                    )
                }
            </StyledFormLabel>
            <DottedBox
                onDrop={e => handleDrop(e)}
                onDragOver={e => handleDragOver(e)}
                onDragEnter={e => handleDragEnter(e)}
                onDragLeave={e => handleDragLeave(e)}
                thumbnail
                >
                <AddAPhotoIcon className="icon"/>
                <input
                    type="file"
                    onChange = {(e) => handleUpload(e, e.target.files)}
                    id="upload-file-thumbnail"
                    style={{display : "none"}}
                    />
                <BlueButton>
                    <label htmlFor="upload-file-thumbnail" style={{width : "inherit", cursor : "pointer"}}>
                        ESCOLHER IMAGEM
                    </label>
                </BlueButton>
                <span style={{marginTop : "6px"}}>Ou arrastar e soltar o arquivo aqui</span>
            </DottedBox>
        </FormControl>
    )
}
