/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.
Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useRef, useState, useEffect, useContext } from 'react';
import axios from 'axios';
import { Grid } from '@material-ui/core';
import CollectionAuthor from '../Components/CollectionAuthor.js';
import VerticalRuler from '../Components/VerticalRuler.js';
import CollectionDescription from '../Components/CollectionDescription.js';
import ResourceList from '../Components/ResourceList.js';
import CollectionCommentSection from '../Components/CollectionCommentSection.js';
import { apiUrl, apiDomain } from '../env';
import styled from 'styled-components';
import DowloadButton from '../Components/CollectionDowloadButton.js';
import Breadcrumbs from "@material-ui/core/Breadcrumbs";
import { Link } from 'react-router-dom';
import FollowCollectionButton from '../Components/FollowCollectionButton';
import { Store } from '../Store.js'

export default function CollectionPage(props) {
	const { state } = useContext(Store);

	const [collection, setCollection] = useState({
		name: '',
		id: 0,
	});
	const collection_id = props.match.params.id;
	const comment_ref = useRef(null);

	useEffect(() => {
		axios.get(apiUrl + '/collections/' + collection_id)
			.then(res => {
				setCollection(Object.assign({}, res.data));
			});
	}, []);

	const handleScrollToComments = () => {
		window.scrollTo(0, comment_ref.current.offsetTop);
	}

	return (
		<>
			<BreadCrumbsDiv>
				<StyledBreadCrumbs>
					<Link to="/">Página Inicial</Link>
					<span>Coleções</span>
				</StyledBreadCrumbs>
			</BreadCrumbsDiv>
			<Grid
				container
				direction="row"
				justify="space-around"
				alignItems="center"
				spacing={4}
			>
				<Grid
					item
					md={3}
				>
					<CollectionAuthor
						author_id={collection.owner ? collection.owner.id : 0}
						name={collection.owner ? collection.owner.name : ""}
						imgsrc={collection.owner ? apiDomain + collection.owner.avatar : ''} />
				</Grid>


				<Grid
					item
					md={5}
				>
					<CollectionDescription
						scrollToComments={handleScrollToComments}
						title={collection.name ? collection.name : ""}
						collection_id={collection.id ? collection.id : 0} />
				</Grid>

				<Grid
					item
					md={3}
				>
					<DowloadButton
						id={collection.id ? collection.id : 0}
					/>
					<div style={{height : 12}}></div>
					<FollowCollectionButton
						user_id={state.currentUser.id}
						collection_id={collection_id} />
				</Grid>
			</Grid>

			<VerticalRuler width={1} height={100} color="rgb(238, 238, 238)" />

			<Grid container item xs={12} direction="row" justify="center" alignItems="center" style={{ backgroundColor: '#f4f4f4' }}>
				<Grid item xs={10} alignItems="center" justify="center">
					<ResourceList resources={
						collection.collection_items ?
							collection.collection_items.map(i => {
								return {
									type: i.collectionable.object_type,
									author: i.collectionable.author,
									published: i.collectionable.published_at,
									title: i.collectionable.name,
									rating: i.collectionable.review_average,
									likeCount: i.collectionable.likes_count,
									liked: i.collectionable.liked,
									avatar: i.collectionable.publisher.avatar,
									thumbnail: i.collectionable.thumbnail,
									tags: i.collectionable.tags.map(t => t),
									id: i.collectionable.id,
								}
							})
							: []
					} />

				</Grid>
				<Grid container item xs={12} style={{ marginTop: 40 }} ref={comment_ref}>
					<CollectionCommentSection id={collection_id} />
				</Grid>
			</Grid>
		</>


		// <Grid container
		// 	direction="row"
		// 	justify="space-around"
		// 	alignItems="center"
		// 	style={mainContainerStyle}>

		// 	<Grid item xs={10} md={3}>
		// 		<CollectionAuthor 
		// 			author_id={collection.owner ? collection.owner.id : 0}
		// 			name={collection.owner ? collection.owner.name : ""}
		// 			imgsrc={collection.owner ? apiDomain+collection.owner.avatar : ''}/>
		// 	</Grid> 

		// 	<VerticalRuler width={1} height={300} color="rgb(238, 238, 238)"/>

		// 	<Grid item xs={10} md={6}>
		// 		<CollectionDescription
		// 			scrollToComments={handleScrollToComments}
		// 			title={collection.name ? collection.name : ""}
		// 			collection_id={collection.id ? collection.id : 0}/>
		// 	</Grid> 

		// 	<Grid container item xs={12} direction="row" justify="center" alignItems="center" style={{backgroundColor: '#f4f4f4'}}>
		// 		<Grid item xs={10}>
		// 			<ResourceList resources={
		// 					collection.collection_items ? 
		// 					collection.collection_items.map(i => {
		// 						return {
		// 							type: i.collectionable.object_type,
		// 							author: i.collectionable.author,
		// 							published: i.collectionable.published_at,
		// 							title: i.collectionable.name,
		// 							rating: i.collectionable.review_average,
		// 							likeCount: i.collectionable.likes_count,
		// 							liked: i.collectionable.liked,
		// 							avatar: i.collectionable.publisher.avatar,
		// 							thumbnail: i.collectionable.thumbnail,
		// 							tags: i.collectionable.tags.map(t => t.name),
		// 							id: i.collectionable.id,
		// 						}
		// 					})
		// 					: []
		// 			}/>

		// 		</Grid>
		// 		<Grid container item xs={12} style={{marginTop: 40}} ref={comment_ref}>
		// 			<CollectionCommentSection id={collection_id}/>
		// 		</Grid>
		// 	</Grid>
		// </Grid>
	);
}

const StyledBreadCrumbs = styled(Breadcrumbs)`
  display: flex;
  justify-content: flex-start;
  max-width: 1170px;
  span {
    color: #a5a5a5;
  }
  a {
    color: #00bcd4;
    text-decoration: none;
  }
`;

const BreadCrumbsDiv = styled.div`
  padding: 10px;
  display: flex;
`;


