/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect, useContext} from 'react'
import {Store} from '../Store.js'
import axios from 'axios'
import {apiUrl, apiDomain} from '../env';
import Grid from '@material-ui/core/Grid';
import UploadFileWrapper from '../Components/UploadPageComponents/UploadFileWrapper.js'
import Alert from '../Components/Alert.js';
import Snackbar from '@material-ui/core/Snackbar';
import {GreyButton, OrangeButton, InfoBox} from '../Components/UploadPageComponents/StyledComponents.js'
import {getAxiosConfig} from '../Components/HelperFunctions/getAxiosConfig.js'
import {Background} from '../Components/UploadPageComponents/StyledComponents'
import LoadingSpinner from '../Components/LoadingSpinner'
import NewTitle from '../Components/UploadPageComponents/Forms/NewTitle.js'
import SobreORecurso from '../Components/UploadPageComponents/Forms/SobreORecurso.js'
import Keywords from '../Components/UploadPageComponents/Forms/Keywords.js'
import Autor from '../Components/UploadPageComponents/Forms/Autor.js'
import TipoDeRecurso from '../Components/UploadPageComponents/Forms/TipoDeRecurso.js'
import Idioma from '../Components/UploadPageComponents/Forms/Idioma.js'
import EducationalStage from '../Components/UploadPageComponents/PartTwoComponents/EducationalStage.js'
import SubjectsAndThemes from '../Components/UploadPageComponents/PartTwoComponents/SubjectsAndThemes.js'
import Licenca from '../Components/UploadPageComponents/PartTwoComponents/Licenca.js'
import {LoadingDiv} from '../Components/UploadPageComponents/PartTwo.js'
import EditThumbnail from '../Components/UploadPageComponents/PartTwoComponents/EditThumbnail.js'
import DisplayThumbnail from '../Components/UploadPageComponents/PartTwoComponents/DisplayThumbnail.js'
import DragAndDropThumbnail from '../Components/UploadPageComponents/PartTwoComponents/DragAndDropThumbnail'


export default function EditLearningObjectPage (props) {
    const recursoId = props.match.params.recursoId
    const {state} = useContext(Store)
    const [learningObject, setLearningObject] = useState({})
    const [objTypes, setObjTypes] = useState([])
    const [languages, setLanguages] = useState([])
    const [eduStages, setEduStages] = useState([])
    const [subjects, setSubjects] = useState([])

    useEffect( () => {
        const config = getAxiosConfig()
        axios.get( (`${apiUrl}/learning_objects/` + recursoId), config
            ).then( (response) => {
                console.log(response.data)
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                setLearningObject(response.data)
                if(response.data.thumbnail) {
                    setThumbnail(response.data.thumbnail)
                    setThumbnailStage('done')
                }
                setUpdatedInfo({...updatedInfo, 'id' : response.data.id})
                toggleLoading(false)
            }, (error) => {console.log(error)}
        )

        axios.get(`${apiUrl}/object_types/`).then(
            (response) => {
                setObjTypes(response.data.sort((a, b) => (a.name) > (b.name) ? 1 : -1))
            }, (error) => {
                console.log(error)
            }
        )

        axios.get(`${apiUrl}/languages/`).then(
            (response) => {
                setLanguages(response.data)
            }, (error) => {
                console.log(error)
            }
        )

        axios.get(`${apiUrl}/educational_stages/`).then(
            (response) => {
                setEduStages(response.data)
            },
            (error) => {console.log(error)}
        )

        axios.get(`${apiUrl}/subjects/`).then(
            (response) => {
                setSubjects(response.data.sort((a,b) => a.name > b.name ? 1 : -1))
            },
            (error) => {console.log(error)}
        )
    }, [state.currentUser.id])

    const [loading, toggleLoading] = useState(true)

    const [updatedInfo, setUpdatedInfo] = useState({})

    const onBlurCallback = (fieldName, payload) => {
        setUpdatedInfo({...updatedInfo, [fieldName] : payload})
    }

    const [snackbarOpen, toggleSnackbar] = useState(false)

    const handleDelete = () => {
        let config = getAxiosConfig()
        axios.delete((`${apiUrl}/learning_objects/` + learningObject.id), config).then(
            (response) => {
                toggleSnackbar(true)
                console.log(response.data)
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                props.history.push("/")
            },
            (error) => {
                console.log(error)
            }
        )
    }

    const handleUpdateInfo = () => {
        let config = getAxiosConfig()
        console.log(updatedInfo)
        let payload = {
            "learning_object" : updatedInfo
        }
        console.log(payload)
        axios.put((`${apiUrl}/learning_objects/` + learningObject.id), payload, config).then(
            (response) => {
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                console.log(response.data); props.history.goBack()
            },
            (error) => {console.log(error)}
        )
    }

    const handlePost = () => {
        let config = getAxiosConfig()
        console.log(updatedInfo)
        let payload = {
            "learning_object" : updatedInfo
        }
        console.log(payload)
        axios.post((`${apiUrl}/learning_objects/` + learningObject.id + '/publish'), payload, config).then(
            (response) => {
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                console.log(response.data);
                props.history.push('/recurso/' + learningObject.id)
            },
            (error) => {console.log(error)}
        )
    }

    const [thumbnailStage, setThumbnailStage] = useState('default')

    const [thumbnail, setThumbnail] = useState('')
    const [tempUrl, setTempUrl] = useState('')

    const acceptFile = (file) => {
        const objectURL = URL.createObjectURL(file)
        console.log('acceptFile: ', file)
        setTempUrl(objectURL)
        setThumbnailStage('editing')
    }
    const updateThumb = (newThumbnail) => {
        setThumbnail(newThumbnail)
        console.log('updateThumb: ', thumbnail)

    }

    const finalizeThumb = () => {
        setThumbnailStage('uploading')
        let config = {
            headers : {
                'Accept': 'application/json',
                'Content-Type': 'application/json',
            }
        }
        config.headers["access-Token"] = sessionStorage.getItem('@portalmec/accessToken');
        config.headers.client = sessionStorage.getItem('@portalmec/clientToken')
        config.headers.uid = sessionStorage.getItem('@portalmec/uid')

        let fdThumb = new FormData()
        fdThumb.set('learning_object[thumbnail]', thumbnail)
        axios.put((`${apiUrl}/learning_objects/` + learningObject.id), fdThumb, config).then(
            (response) => {
                setThumbnailStage('done')
                console.log(response.data)
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                if(response.data.thumbnail) {
                    setThumbnail(response.data.thumbnail)
                    setThumbnailStage('done')
                }
            },
            () => {
                setThumbnailStage('default')
            }
        )
    }

    const handleDeleteThumbnail = () => {
        let config = {
            headers : {
                'Accept': 'application/json',
                'Content-Type': 'application/json',
            }
        }
        config.headers["access-Token"] = sessionStorage.getItem('@portalmec/accessToken');
        config.headers.client = sessionStorage.getItem('@portalmec/clientToken')
        config.headers.uid = sessionStorage.getItem('@portalmec/uid')

        let fdThumb = new FormData()
        fdThumb.set('learning_object[thumbnail]', null)
        axios.put((`${apiUrl}/learning_objects/` + learningObject.id), fdThumb, config).then(
            (response) => {
                setThumbnailStage('default')
                console.log(response.data)
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
            },
            (error) => {
                console.log(error)
            }
        )
    }

    const chooseRenderStageThumbnail = () => {
        switch(thumbnailStage) {
            case 'uploading':
               return (<LoadingDiv/>)
            case 'done':
               return (<DisplayThumbnail acceptFile={acceptFile} thumbnail={`${apiDomain}` + thumbnail} onEditPage={true} handleDelete={handleDeleteThumbnail}/>)
            case 'editing':
               return (<EditThumbnail finalizeThumb={finalizeThumb} tempImgURL={tempUrl} updateThumb={updateThumb}/>)
            default :
               return (<DragAndDropThumbnail acceptFile={acceptFile} onEditPage={true}/>)

        }
    }
    return (
        <React.Fragment>
            <Snackbar open={snackbarOpen} autoHideDuration={1000} onClose={() => {toggleSnackbar(false)}}
            anchorOrigin = {{ vertical:'top', horizontal:'right' }}
            >
                <Alert severity="info" style={{backgroundColor:"#00acc1"}}>
                    Recurso excluido com sucesso!
                </Alert>
            </Snackbar>
        {
            !loading ?
            (
                <Background>
                    <div className="container">
                            <Grid container spacing={2}>
                                <Grid item md={4} xs={12}>
                                    <UploadFileWrapper draftID={recursoId} prevFile={learningObject.attachments ? learningObject.attachments[0] : null}/>
                                </Grid>
                                <Grid item md={8} xs={12}>
                                    <InfoBox>
                                        <form onSubmit={handlePost}>
                                            <div className="cabecalho">
                                                <h2>Editar Recurso</h2>
                                            </div>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                {chooseRenderStageThumbnail()}
                                            </Grid>

                                            <Grid container style={{paddingLeft : "15px", paddingRight : "15px"}}>
                                                <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                    <NewTitle draftID={learningObject.id} initialValue={learningObject.name}
                                                        onBlurCallback={onBlurCallback}
                                                        />
                                                </Grid>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                <SobreORecurso draftID={learningObject.id} initialValue={learningObject.description} onBlurCallback={onBlurCallback}/>
                                            </Grid>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                <Keywords  draftID={learningObject.id} initialValue={learningObject.tags.map((tag) => tag.name)}
                                                    onBlurCallback={onBlurCallback}/>
                                            </Grid>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                <Autor  draftID={learningObject.id}
                                                    initialValue={
                                                        learningObject.author === state.currentUser.name ?
                                                        0 : 1
                                                    }
                                                    initialOutroAutor={
                                                        learningObject.author !== state.currentUser.name ?
                                                        learningObject.author : ''
                                                    }
                                                    onBlurCallback={onBlurCallback}
                                                     />
                                            </Grid>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                <TipoDeRecurso objTypes={objTypes} draftID={learningObject.id}
                                                    initialValue={learningObject.object_type !== null ? objTypes.filter((type) => type.name === learningObject.object_type)[0].id : null} onBlurCallback={onBlurCallback} />
                                            </Grid>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                              <Idioma languages={languages}  draftID={learningObject.id} initialValue={learningObject.language.map((language) => language.name)} initialIDValues={learningObject.language.map((language) => language.id)}
                                                  onBlurCallback={onBlurCallback} />
                                            </Grid>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                <EducationalStage draftID={learningObject.id} eduStages={eduStages} initialValue={learningObject.educational_stages.map((stage) => String(stage.id))} onBlurCallback={onBlurCallback}
                                                    />
                                            </Grid>

                                            <SubjectsAndThemes draftId={learningObject.id} subjects={subjects} initialValue={learningObject.subjects.map(subject => String(subject.id))} onBlurCallback={onBlurCallback}/>

                                            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                                                <Licenca draftID={learningObject.id} initialValue={learningObject.license ? learningObject.license.id : null} onBlurCallback={onBlurCallback}/>
                                            </Grid>

                                            <Grid item xs={12}>
                                                <div style={{display : "flex", justifyContent : "center"}}>
                                                        <GreyButton onClick={handleDelete}>
                                                            <span className="button-text">
                                                            EXCLUIR
                                                            </span>
                                                        </GreyButton>

                                                        <GreyButton onClick={props.history.goBack}>
                                                            <span className="button-text">
                                                            CANCELAR
                                                            </span>
                                                        </GreyButton>

                                                    <OrangeButton onClick={() => {handleUpdateInfo()}}>
                                                        SALVAR ALTERAÇÕES
                                                        </OrangeButton>

                                                    {
                                                        learningObject.state === "draft" &&
                                                            <OrangeButton type="submit">
                                                            PUBLICAR RECURSO
                                                            </OrangeButton>
                                                    }
                                                </div>
                                            </Grid>

                                            <Grid item xs={12} style={{marginTop : "20px"}}>
                                                <span style={{marginTop : "20px", fontWeight : "200", color : "#a5a5a5", paddingLeft : "10px"}}>
                                                    * Campos obrigatórios
                                                </span>
                                            </Grid>
                                            </Grid>

                                        </form>
                                    </InfoBox>
                                </Grid>
                            </Grid>
                    </div>
                </Background>
            )
            :
            (
                <LoadingSpinner text={"CARREGANDO"}/>
            )
        }
        </React.Fragment>
    )
}
