/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState } from 'react';
import styled from 'styled-components';
import Tabs from '@material-ui/core/Tabs'
import Tab from '@material-ui/core/Tab';
import Breadcrumbs from '@material-ui/core/Breadcrumbs';
import Grid from '@material-ui/core/Grid';
import ParticipandoRede from '../../img/ajuda/Participando_da_rede.png';
import How from '../../Components/HelpCenter/TabsNetPart/How'
import What from '../../Components/HelpCenter/TabsNetPart/What'
import CardEncontrando from '../../Components/HelpCenter/Cards/CardEncontrando';
import CardPublicando from '../../Components/HelpCenter/Cards/CardPublicando';
import CardGerenciando from '../../Components/HelpCenter/Cards/CardGerenciando';
import  { Link } from 'react-router-dom';







export default function TabNetPart (props) {
  const tabs= [
    'Como comentar ou avaliar um recurso?',
    'Que tipo de comentário posso fazer sobre o recurso?',
    'Participando da Rede'
  ]
  
  const [tabValue, setTabValue] = useState(props.location.state === "undefined" ? 0 : props.location.state);

  const handleChangeTab = (e, newValue) => {
    setTabValue(newValue)
}



  return(
    <div style={{backgroundColor:"#f4f4f4"}}>
      <link href="https://fonts.googleapis.com/css?family=Pompiere|Roboto:500,400&display=swap" rel="stylesheet"/>
      
      <Secao>
        <BreadCrumbsDiv>
          <StyledBreadCrumbs>
            <Link to="/" >
              Página Inicial
            </Link>
            <Link to="ajuda" >
              Ajuda
            </Link>
            
            <span>
              {tabs[2]}
            </span>


          </StyledBreadCrumbs>

        </BreadCrumbsDiv>
        <Grid container spacing={4}>
          <Grid item xs={3}>
            <Menu>
              <h4>{tabs[2]}</h4>
              <TabsStyled orientation = "vertical"
                          variant = "scrollable"
                          value = {tabValue}
                          onChange = {handleChangeTab}
                          TabIndicatorProps = {{style:{display: "none"}}}
              >
              <TabStyled label={tabs[0]}></TabStyled>
              <TabStyled label={tabs[1]}></TabStyled>
              </TabsStyled>
              <br/>
              <div className="voltarInicio">
                <a href="ajuda">VOLTAR AO ÍNICIO</a>
              </div>
              <hr/>
              <div className="procurava">
                Não encontrou o que procurava? Entre em 
                <a href="contato"> contato</a>
              </div>
            </Menu>
          </Grid>

          <Grid item xs={9}>
            <Principal>
              <div className="fixo">
                <img src={ParticipandoRede} alt="Participando da Rede"/>
                <span>{tabs[2]}</span>
              </div>
              {tabValue === 0 && <How title={tabs[0]}/>}
              {tabValue === 1 && <What title={tabs[1]}/>}
              <div className="resultadosProcura">
                <span>Não era bem o que você procurava?</span>
                <div className="subtitulo">
                  <span>Você pode navegar pelos tópicos de ajuda ou entrar em <a href="contato">Contato</a>.</span>
                </div>
              </div>
              <Grid style={{marginBottom:"50px"}} container spacing={2}>
                <Grid item xs={4}>
                  <CardPublicando/>
                </Grid>
                <Grid item xs={4}>
                  <CardEncontrando/>
                </Grid>
                <Grid item xs={4}>
                  <CardGerenciando/>
                </Grid>
              </Grid>


            </Principal>
          </Grid>  
        </Grid>        


      </Secao>
    </div>
  );
}
const StyledBreadCrumbs = styled(Breadcrumbs)`
  display : flex;
  justify-content : flex-start;
  max-width : 1170px;
  span {
    color : #a5a5a5;
  }
  a {
    color: #00bcd4;
    text-decoration: none;
  }

`

const BreadCrumbsDiv = styled.div`

  padding : 10px;
  display : flex;
`


const Principal = styled.div`
  .fixo {
    
    height: 40px;
    text-align: center;
    background-color: #fff;
    box-shadow: 0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24);
    padding: 30px;
    margin-bottom: 30px;
    color: #666;


    img {
      height: 50px;
      width: 50px;
      margin-right: 40px;
      vertical-align: middle;

    }

    span {
      font-size: 20px;
      vertical-align: ;
    }

    

  }
  .resultadosProcura {
    text-align: center;
    margin-block: 30px;
    padding-inline: 15px;
    color: #666;
    span {
      font-size: 24px;
    }
    .subtitulo {
      margin-top: 10px;

      span {
        font-size: 15px
      }

      a {
        font-size: 15px;
        padding: 0;
        color:#00bcd4;
        text-decoration: none;
      }

    }
  }

`

const TabsStyled = styled(Tabs)`
  
  .Mui-selected {
    background-color: #e7e4e4;
  }

  .MuiTab-root{
    text-transform: none !important;
  }

`

const TabStyled = styled(Tab)`
    
  padding: 4px 15px !important;
  font-weight: 500;
  font-size: 14px !important;
  border-radius: 4px !important;


  


  &:hover {
    background-color: #e7e4e4;
  }
`


const Menu = styled.div`
  width: auto;
  background-color: #fff;
  color: #666;
  padding-block: 10px;
  box-shadow: 0 1px 3px rgba(0,0,0,.12),0 1px 2px  rgba(0,0,0,.24);

  h4 {
    padding-inline: 15px;
    font-size: 18px;
    margin-block: 10px;
    font-weight: 500;
    line-height: 1.1;
  }

  .voltarInicio {
    padding: 4px 15px;
    font-size: 15px;
    text-align: center;
    a {
      font-size: 15px;
      padding: 0;
      color:#00bcd4;
      text-decoration: none;
    }
  }

  hr {
    border: 0;
    border-top: 1px solid #ccc;
    margin-top: 20px;
    margin-bottom: 20px;
  }

  .procurava {
    padding: 4px 15px;
    font-size: 15px;
    text-align: center;

    a {
      font-size: 15px;
      padding: 0;
      color:#00bcd4;
      text-decoration: none;
    }

  }

`

const Secao = styled.div`
  width: 1138px;
  margin-inline: auto;

`
